@@ -39,7 +39,7 @@ from weasyprint import CSS
 
 from wbwriter.models.publication_models import Publication
 from wbwriter.pdf_generator import PdfGenerator
-from wbwriter.publication_parser import ParserValidationException
+from wbwriter.publication_parser import ParserValidationError
 from wbwriter.typings import ArticleDTO
 
 from .mixins import PublishableMixin
@@ -167,7 +167,7 @@ class DependantArticle(WBModel):
     )
 
     @classmethod
-    def get_endpoint_basename(self):
+    def get_endpoint_basename(cls):
         return "wbwriter:dependantarticle"
 
     @classmethod
@@ -789,7 +789,7 @@ class Article(CloneMixin, TagModelMixin, PublishableMixin, WBModel):
                         self._build_dto(),
                         date.today(),
                     ).is_valid()
-                except ParserValidationException as e:
+                except ParserValidationError as e:
                     errors["non_field_errors"] = e.errors
                 except ModuleNotFoundError:
                     errors["non_field_errors"] = [gettext_lazy("invalid parser")]
@@ -1175,7 +1175,7 @@ class Article(CloneMixin, TagModelMixin, PublishableMixin, WBModel):
         return mapping
 
     @classmethod
-    def get_endpoint_basename(self):
+    def get_endpoint_basename(cls):
         return "wbwriter:article"
 
     @classmethod
